depends = ('ITKPyBase', 'ITKCommon', )
templates = (
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2ISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3ISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2ISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3ISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2ISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3ISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2ISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3ISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUC2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUC3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUC2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUC3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUC2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUC3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUC2IF2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUC3IF3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IUS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IUS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IF2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IF3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IF2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IF3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IF2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IF3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS2IF2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterISS3IF3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2ISS2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3ISS3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2ISS2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3ISS3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2ISS2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3ISS3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2ISS2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3ISS3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUS2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUS3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUS2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUS3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUS2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUS3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUS2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUS3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IF2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IF3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IF2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IF3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IF2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IF3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IF2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IF3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2ISS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3ISS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2ISS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3ISS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2ISS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3ISS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2ISS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3ISS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUC2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUC3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUC2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUC3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUC2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUC3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUC2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUC3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IF2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IF3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IF2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IF3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IF2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IF3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS2IF2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUS3IF3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2ISS2ISS2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3ISS3ISS3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2ISS2IUC2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3ISS3IUC3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2ISS2IUS2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3ISS3IUS3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2ISS2IF2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3ISS3IF3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUC2ISS2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUC3ISS3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUC2IUC2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUC3IUC3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUC2IUS2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUC3IUS3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUC2IF2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUC3IF3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUS2ISS2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUS3ISS3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUS2IUC2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUS3IUC3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUS2IUS2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUS3IUS3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IUS2IF2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IUS3IF3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IF2ISS2', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IF3ISS3', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IF2IUC2', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IF3IUC3', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IF2IUS2', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IF3IUS3', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >, itk::Image< float,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF22ISS2IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF23ISS3IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF32ISS2IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF33ISS3IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF42ISS2IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF43ISS3IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF22IUC2IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF23IUC3IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF32IUC2IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF33IUC3IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF42IUC2IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF43IUC3IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF22IUS2IVF22', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF23IUS3IVF23', True, 'itk::Image< itk::Vector< float,2 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF32IUS2IVF32', True, 'itk::Image< itk::Vector< float,3 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF33IUS3IVF33', True, 'itk::Image< itk::Vector< float,3 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF42IUS2IVF42', True, 'itk::Image< itk::Vector< float,4 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIVF43IUS3IVF43', True, 'itk::Image< itk::Vector< float,4 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF22ISS2ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF23ISS3ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF32ISS2ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF33ISS3ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF42ISS2ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< signed short,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF43ISS3ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< signed short,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF22IUC2ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF23IUC3ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF32IUC2ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF33IUC3ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF42IUC2ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF43IUC3ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF22IUS2ICVF22', True, 'itk::Image< itk::CovariantVector< float,2 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::CovariantVector< float,2 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF23IUS3ICVF23', True, 'itk::Image< itk::CovariantVector< float,2 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::CovariantVector< float,2 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF32IUS2ICVF32', True, 'itk::Image< itk::CovariantVector< float,3 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::CovariantVector< float,3 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF33IUS3ICVF33', True, 'itk::Image< itk::CovariantVector< float,3 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::CovariantVector< float,3 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF42IUS2ICVF42', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::CovariantVector< float,4 >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICVF43IUS3ICVF43', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::CovariantVector< float,4 >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC2ISS2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< signed short,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC3ISS3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< signed short,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC2IUC2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC3IUC3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC2IUS2IRGBUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBUC3IUS3IRGBUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC2ISS2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< signed short,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC3ISS3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< signed short,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC2IUC2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC3IUC3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC2IUS2IRGBAUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::RGBAPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIRGBAUC3IUS3IRGBAUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::RGBAPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF2ISS2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< signed short,2 >, itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF3ISS3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< signed short,3 >, itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF2IUC2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned char,2 >, itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF3IUC3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned char,3 >, itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF2IUS2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned short,2 >, itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF3IUS3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned short,3 >, itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF2IF2ICF2', True, 'itk::Image< float,2 >,itk::Image< float,2 >,itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF2IF2ICF2', True, 'itk::Image< std::complex< float >,2 >,itk::Image< float,2 >,itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIF3IF3ICF3', True, 'itk::Image< float,3 >,itk::Image< float,3 >,itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF3IF3ICF3', True, 'itk::Image< std::complex< float >,3 >,itk::Image< float,3 >,itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF2ICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterICF3ICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2ISS2IRGBUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3ISS3IRGBUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUC2IRGBUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUC3IRGBUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUS2IRGBUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUS3IRGBUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC2IUL2IRGBUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned long,2 >, itk::Image< itk::RGBPixel< unsigned char >,2 >'),
  ('BinaryGeneratorImageFilter', 'itk::BinaryGeneratorImageFilter', 'itkBinaryGeneratorImageFilterIUC3IUL3IRGBUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned long,3 >, itk::Image< itk::RGBPixel< unsigned char >,3 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('BoxImageFilter', 'itk::BoxImageFilter', 'itkBoxImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF2ISS2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF3ISS3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF2IUC2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF3IUC3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF2IUS2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF3IUS3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL2ISS2', True, 'itk::Image< unsigned long long,2 >, itk::Image< signed short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL3ISS3', True, 'itk::Image< unsigned long long,3 >, itk::Image< signed short,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL2IUC2', True, 'itk::Image< unsigned long long,2 >, itk::Image< unsigned char,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL3IUC3', True, 'itk::Image< unsigned long long,3 >, itk::Image< unsigned char,3 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL2IUS2', True, 'itk::Image< unsigned long long,2 >, itk::Image< unsigned short,2 >'),
  ('CastImageFilter', 'itk::CastImageFilter', 'itkCastImageFilterIULL3IUS3', True, 'itk::Image< unsigned long long,3 >, itk::Image< unsigned short,3 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('NoiseImageFilter', 'itk::NoiseImageFilter', 'itkNoiseImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('RecursiveSeparableImageFilter', 'itk::RecursiveSeparableImageFilter', 'itkRecursiveSeparableImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS2IF2', True, 'itk::Image< signed short,2 >, itk::Image< float,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS3IF3', True, 'itk::Image< signed short,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS2ICF2', True, 'itk::Image< signed short,2 >, itk::Image< std::complex< float >,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterISS3ICF3', True, 'itk::Image< signed short,3 >, itk::Image< std::complex< float >,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC2IF2', True, 'itk::Image< unsigned char,2 >, itk::Image< float,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC3IF3', True, 'itk::Image< unsigned char,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC2ICF2', True, 'itk::Image< unsigned char,2 >, itk::Image< std::complex< float >,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUC3ICF3', True, 'itk::Image< unsigned char,3 >, itk::Image< std::complex< float >,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS2IF2', True, 'itk::Image< unsigned short,2 >, itk::Image< float,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS3IF3', True, 'itk::Image< unsigned short,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS2ICF2', True, 'itk::Image< unsigned short,2 >, itk::Image< std::complex< float >,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIUS3ICF3', True, 'itk::Image< unsigned short,3 >, itk::Image< std::complex< float >,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF2ISS2', True, 'itk::Image< float,2 >, itk::Image< signed short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF3ISS3', True, 'itk::Image< float,3 >, itk::Image< signed short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF2IUC2', True, 'itk::Image< float,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF3IUC3', True, 'itk::Image< float,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF2IUS2', True, 'itk::Image< float,2 >, itk::Image< unsigned short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF3IUS3', True, 'itk::Image< float,3 >, itk::Image< unsigned short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF2IF2', True, 'itk::Image< float,2 >, itk::Image< float,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF3IF3', True, 'itk::Image< float,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF2ICF2', True, 'itk::Image< float,2 >, itk::Image< std::complex< float >,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIF3ICF3', True, 'itk::Image< float,3 >, itk::Image< std::complex< float >,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF2ISS2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< signed short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF3ISS3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< signed short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF2IUC2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF3IUC3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF2IUS2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< unsigned short,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF3IUS3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< unsigned short,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF2IF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< float,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF3IF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< float,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF2ICF2', True, 'itk::Image< std::complex< float >,2 >, itk::Image< std::complex< float >,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterICF3ICF3', True, 'itk::Image< std::complex< float >,3 >, itk::Image< std::complex< float >,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBUC2IUC2', True, 'itk::Image< itk::RGBPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBUC3IUC3', True, 'itk::Image< itk::RGBPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBAUC2IUC2', True, 'itk::Image< itk::RGBAPixel< unsigned char >,2 >, itk::Image< unsigned char,2 >'),
  ('UnaryGeneratorImageFilter', 'itk::UnaryGeneratorImageFilter', 'itkUnaryGeneratorImageFilterIRGBAUC3IUC3', True, 'itk::Image< itk::RGBAPixel< unsigned char >,3 >, itk::Image< unsigned char,3 >'),
)
snake_case_functions = ('recursive_separable_image_filter', 'in_place_image_filter', 'cast_image_filter', 'box_image_filter', 'unary_generator_image_filter', 'binary_generator_image_filter', 'noise_image_filter', )
